@@ -1,13 +1,16 @@
 """This module implements the class AcceptsMoistureMeasurement."""
 
+from ml.fml40.features.properties.values.documents.reports.soil_moisture_measurement import (
+    SoilMoistureMeasurement,
+)
 from ml.ml40.features.functionalities.functionality import Functionality
-from ml.fml40.features.properties.values.documents.reports.soil_moisture_measurement import SoilMoistureMeasurement
 
 
 class AcceptsMoistureMeasurement(Functionality):
     """This functionality signalizes that SoilMoistureMeasurements can be
     processed."""
-    def __init__(self, name="", identifier=""):
+
+    def __init__(self, namespace="fml40", name="", identifier="", parent=None):
         """Initializes the object.
 
         :param name:  Object name
@@ -15,11 +18,9 @@ class AcceptsMoistureMeasurement(Functionality):
 
         """
         super().__init__(
-            name=name,
-            identifier=identifier)
+            namespace=namespace, name=name, identifier=identifier, parent=parent
+        )
 
     def acceptMoistureMeasurement(self, input: SoilMoistureMeasurement):
-        """Accepts the given SoilMoistureMeasurement.
-
-        """
+        """Accepts the given SoilMoistureMeasurement."""
         pass
