@@ -2,10 +2,10 @@ from ml.ml40.features.functionalities.functionality import Functionality
 
 
 class Grabs(Functionality):
-    def __init__(self, name="", identifier=""):
+    def __init__(self, namespace="fml40", name="", identifier="", parent=None):
         super().__init__(
-            name=name,
-            identifier=identifier)
+            namespace=namespace, name=name, identifier=identifier, parent=parent
+        )
 
     def close(self):
         pass
