@@ -3,7 +3,7 @@ from ml.ml40.features.properties.values.force import Force
 
 
 class ProvidesForceData(Functionality):
-    def __init__(self, name="", identifier=""):
+    def __init__(self, namespace="mml40", name="", identifier="", parent=None):
         """Initializes the object.
 
         :param name: Object name
@@ -11,14 +11,8 @@ class ProvidesForceData(Functionality):
 
         """
         super().__init__(
-            name=name,
-            identifier=identifier)
-
-    def compileForceWithMaterial(self, stretchData, materialType) -> [Force]:
-        pass
-
-    def compileForceWithGeometry(self, stretchData, geometryType) -> [Force]:
-        pass
+            namespace=namespace, name=name, identifier=identifier, parent=parent
+        )
 
     def getMaxForce(self) -> Force:
         pass
@@ -31,4 +25,3 @@ class ProvidesForceData(Functionality):
 
     def getForceDataSeries(self, startTime, endTime) -> [Force]:
         pass
-
